Documentation
¶
Index ¶
- type APIClient
- type APIError
- type Album
- type AlbumGetInfoResponse
- type AlbumGetTagsResponse
- type AlbumGetTopTagsResponse
- type AlbumList
- type AlbumSearchResponse
- type AlbumService
- func (s *AlbumService) AddTags(ctx context.Context, artist, album, tags string) error
- func (s *AlbumService) GetInfo(ctx context.Context, artist, album string, options url.Values) (*AlbumGetInfoResponse, error)
- func (s *AlbumService) GetTags(ctx context.Context, artist, album string, options url.Values) (*AlbumGetTagsResponse, error)
- func (s *AlbumService) GetTopTags(ctx context.Context, artist, album string, options url.Values) (*AlbumGetTopTagsResponse, error)
- func (s *AlbumService) RemoveTag(ctx context.Context, artist, album, tag string) error
- func (s *AlbumService) Search(ctx context.Context, album string, options url.Values) (*AlbumSearchResponse, error)
- type Artist
- type ArtistCorrection
- type ArtistGetCorrectionResponse
- type ArtistGetInfoResponse
- type ArtistGetSimilarResponse
- type ArtistGetTagsResponse
- type ArtistGetTopAlbumsResponse
- type ArtistGetTopTagsResponse
- type ArtistGetTopTracksResponse
- type ArtistList
- type ArtistSearchResponse
- type ArtistService
- func (s *ArtistService) AddTags(ctx context.Context, artist, tags string) error
- func (s *ArtistService) GetCorrection(ctx context.Context, artist string) (*ArtistGetCorrectionResponse, error)
- func (s *ArtistService) GetInfo(ctx context.Context, artist string, options url.Values) (*ArtistGetInfoResponse, error)
- func (s *ArtistService) GetSimilar(ctx context.Context, artist string, options url.Values) (*ArtistGetSimilarResponse, error)
- func (s *ArtistService) GetTags(ctx context.Context, artist string, options url.Values) (*ArtistGetTagsResponse, error)
- func (s *ArtistService) GetTopAlbums(ctx context.Context, artist string, options url.Values) (*ArtistGetTopAlbumsResponse, error)
- func (s *ArtistService) GetTopTags(ctx context.Context, artist string, options url.Values) (*ArtistGetTopTagsResponse, error)
- func (s *ArtistService) GetTopTracks(ctx context.Context, artist string, options url.Values) (*ArtistGetTopTracksResponse, error)
- func (s *ArtistService) RemoveTag(ctx context.Context, artist, tag string) error
- func (s *ArtistService) Search(ctx context.Context, artist string, options url.Values) (*ArtistSearchResponse, error)
- type Attr
- type AuthService
- func (s *AuthService) AuthURL(token string) string
- func (s *AuthService) GetMobileSession(ctx context.Context, username, password string) (Session, error)
- func (s *AuthService) GetSession(ctx context.Context, token string) (Session, error)
- func (s *AuthService) GetToken(ctx context.Context) (string, error)
- type Bio
- type Chart
- type ChartGetTopArtistsResponse
- type ChartGetTopTagsResponse
- type ChartGetTopTracksResponse
- type ChartList
- type ChartService
- func (s *ChartService) GetTopArtists(ctx context.Context, options url.Values) (*ChartGetTopArtistsResponse, error)
- func (s *ChartService) GetTopTags(ctx context.Context, options url.Values) (*ChartGetTopTagsResponse, error)
- func (s *ChartService) GetTopTracks(ctx context.Context, options url.Values) (*ChartGetTopTracksResponse, error)
- type Client
- type Date
- type Friend
- type FriendList
- type GeoGetTopArtistsResponse
- type GeoGetTopTracksResponse
- type GeoService
- type Image
- type LibraryGetArtistsResponse
- type LibraryService
- type Option
- type ScrobbleResult
- type ScrobbleResults
- type Session
- type Similar
- type Stats
- type Streamable
- type Tag
- type TagGetInfoResponse
- type TagGetSimilarResponse
- type TagGetTopAlbumsResponse
- type TagGetTopArtistsResponse
- type TagGetTopTagsResponse
- type TagGetTopTracksResponse
- type TagGetWeeklyChartListResponse
- type TagList
- type TagService
- func (s *TagService) GetInfo(ctx context.Context, tag string, options url.Values) (*TagGetInfoResponse, error)
- func (s *TagService) GetSimilar(ctx context.Context, tag string, options url.Values) (*TagGetSimilarResponse, error)
- func (s *TagService) GetTopAlbums(ctx context.Context, tag string, options url.Values) (*TagGetTopAlbumsResponse, error)
- func (s *TagService) GetTopArtists(ctx context.Context, tag string, options url.Values) (*TagGetTopArtistsResponse, error)
- func (s *TagService) GetTopTags(ctx context.Context, options url.Values) (*TagGetTopTagsResponse, error)
- func (s *TagService) GetTopTracks(ctx context.Context, tag string, options url.Values) (*TagGetTopTracksResponse, error)
- func (s *TagService) GetWeeklyChartList(ctx context.Context, tag string, options url.Values) (*TagGetWeeklyChartListResponse, error)
- type Tags
- type TopTags
- type Track
- type TrackAttr
- type TrackCorrection
- type TrackCorrectionEntity
- type TrackGetCorrectionResponse
- type TrackGetInfoResponse
- type TrackGetSimilarResponse
- type TrackGetTagsResponse
- type TrackGetTopTagsResponse
- type TrackList
- type TrackNowPlayingResponse
- type TrackScrobbleResponse
- type TrackSearchResponse
- type TrackService
- func (s *TrackService) AddTags(ctx context.Context, artist, track, tags string) error
- func (s *TrackService) GetCorrection(ctx context.Context, artist, track string) (*TrackGetCorrectionResponse, error)
- func (s *TrackService) GetInfo(ctx context.Context, artist, track string, options url.Values) (*TrackGetInfoResponse, error)
- func (s *TrackService) GetSimilar(ctx context.Context, artist, track string, options url.Values) (*TrackGetSimilarResponse, error)
- func (s *TrackService) GetTags(ctx context.Context, artist, track string, options url.Values) (*TrackGetTagsResponse, error)
- func (s *TrackService) GetTopTags(ctx context.Context, artist, track string, options url.Values) (*TrackGetTopTagsResponse, error)
- func (s *TrackService) Love(ctx context.Context, artist, track string) error
- func (s *TrackService) RemoveTag(ctx context.Context, artist, track, tag string) error
- func (s *TrackService) Scrobble(ctx context.Context, artist, track string, timestamp int64, options url.Values) (*TrackScrobbleResponse, error)
- func (s *TrackService) Search(ctx context.Context, track string, options url.Values) (*TrackSearchResponse, error)
- func (s *TrackService) Unlove(ctx context.Context, artist, track string) error
- func (s *TrackService) UpdateNowPlaying(ctx context.Context, artist, track string, options url.Values) (*TrackNowPlayingResponse, error)
- type Tracks
- type User
- type UserGetFriendsResponse
- type UserGetInfoResponse
- type UserGetLovedTracksResponse
- type UserGetPersonalTagsResponse
- type UserGetRecentTracksResponse
- type UserGetTopAlbumsResponse
- type UserGetTopArtistsResponse
- type UserGetTopTagsResponse
- type UserGetTopTracksResponse
- type UserGetWeeklyAlbumChartResponse
- type UserGetWeeklyArtistChartResponse
- type UserGetWeeklyChartListResponse
- type UserGetWeeklyTrackChartResponse
- type UserService
- func (s *UserService) GetFriends(ctx context.Context, user string, options url.Values) (*UserGetFriendsResponse, error)
- func (s *UserService) GetInfo(ctx context.Context, user string, options url.Values) (*UserGetInfoResponse, error)
- func (s *UserService) GetLovedTracks(ctx context.Context, user string, options url.Values) (*UserGetLovedTracksResponse, error)
- func (s *UserService) GetPersonalTags(ctx context.Context, user, tag, taggingType string, options url.Values) (*UserGetPersonalTagsResponse, error)
- func (s *UserService) GetRecentTracks(ctx context.Context, user string, options url.Values) (*UserGetRecentTracksResponse, error)
- func (s *UserService) GetTopAlbums(ctx context.Context, user string, options url.Values) (*UserGetTopAlbumsResponse, error)
- func (s *UserService) GetTopArtists(ctx context.Context, user string, options url.Values) (*UserGetTopArtistsResponse, error)
- func (s *UserService) GetTopTags(ctx context.Context, user string, options url.Values) (*UserGetTopTagsResponse, error)
- func (s *UserService) GetTopTracks(ctx context.Context, user string, options url.Values) (*UserGetTopTracksResponse, error)
- func (s *UserService) GetWeeklyAlbumChart(ctx context.Context, user string, options url.Values) (*UserGetWeeklyAlbumChartResponse, error)
- func (s *UserService) GetWeeklyArtistChart(ctx context.Context, user string, options url.Values) (*UserGetWeeklyArtistChartResponse, error)
- func (s *UserService) GetWeeklyChartList(ctx context.Context, user string) (*UserGetWeeklyChartListResponse, error)
- func (s *UserService) GetWeeklyTrackChart(ctx context.Context, user string, options url.Values) (*UserGetWeeklyTrackChartResponse, error)
- type Wiki
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type APIClient ¶
type APIClient interface {
Call(ctx context.Context, httpMethod string, apiMethod string, params url.Values, target interface{}) error
}
APIClient defines the interface required by the services.
type Album ¶
type Album struct {
Name string `json:"name,omitempty"`
Title string `json:"title,omitempty"` // Some endpoints use "title"
Text string `json:"#text,omitempty"` // Some endpoints use "#text" for name
Artist interface{} `json:"artist,omitempty"` // Can be string or Artist struct
ID string `json:"id,omitempty"`
MBID string `json:"mbid,omitempty"`
URL string `json:"url,omitempty"`
ReleaseDate string `json:"releasedate,omitempty"`
Image []Image `json:"image,omitempty"`
Listeners string `json:"listeners,omitempty"`
Playcount json.Number `json:"playcount,omitempty"`
TopTags *TopTags `json:"toptags,omitempty"`
Tracks *Tracks `json:"tracks,omitempty"`
Wiki *Wiki `json:"wiki,omitempty"`
Streamable string `json:"streamable,omitempty"`
Rank json.Number `json:"rank,omitempty"`
}
Album represents a Last.fm album.
type AlbumGetInfoResponse ¶
type AlbumGetInfoResponse struct {
Album Album `json:"album"`
}
AlbumGetInfoResponse is the response from album.getInfo.
type AlbumGetTagsResponse ¶
type AlbumGetTagsResponse struct {
Tags struct {
Tag TagList `json:"tag"`
Artist string `json:"artist"`
Album string `json:"album"`
} `json:"tags"`
}
AlbumGetTagsResponse is the response from album.getTags.
type AlbumGetTopTagsResponse ¶
type AlbumGetTopTagsResponse struct {
TopTags struct {
Tag TagList `json:"tag"`
Artist string `json:"artist"`
Album string `json:"album"`
} `json:"toptags"`
}
AlbumGetTopTagsResponse is the response from album.getTopTags.
type AlbumList ¶
type AlbumList []Album
AlbumList is a slice of Album that handles both a single object and an array in JSON.
func (*AlbumList) UnmarshalJSON ¶
UnmarshalJSON implements json.Unmarshaler.
type AlbumSearchResponse ¶
type AlbumSearchResponse struct {
Results struct {
AlbumMatches struct {
Album AlbumList `json:"album"`
} `json:"albummatches"`
} `json:"results"`
}
AlbumSearchResponse is the response from album.search.
type AlbumService ¶
type AlbumService struct {
// contains filtered or unexported fields
}
AlbumService handles API calls related to albums.
func NewAlbumService ¶
func NewAlbumService(client APIClient) *AlbumService
NewAlbumService creates a new album service.
func (*AlbumService) AddTags ¶
func (s *AlbumService) AddTags(ctx context.Context, artist, album, tags string) error
AddTags tags an album using a list of user supplied tags. See: http://www.last.fm/api/show/album.addTags
func (*AlbumService) GetInfo ¶
func (s *AlbumService) GetInfo(ctx context.Context, artist, album string, options url.Values) (*AlbumGetInfoResponse, error)
GetInfo gets the metadata and tracklist for an album. See: http://www.last.fm/api/show/album.getInfo
func (*AlbumService) GetTags ¶
func (s *AlbumService) GetTags(ctx context.Context, artist, album string, options url.Values) (*AlbumGetTagsResponse, error)
GetTags gets the tags applied by an individual user to an album. See: http://www.last.fm/api/show/album.getTags
func (*AlbumService) GetTopTags ¶
func (s *AlbumService) GetTopTags(ctx context.Context, artist, album string, options url.Values) (*AlbumGetTopTagsResponse, error)
GetTopTags gets the top tags for an album. See: http://www.last.fm/api/show/album.getTopTags
func (*AlbumService) RemoveTag ¶
func (s *AlbumService) RemoveTag(ctx context.Context, artist, album, tag string) error
RemoveTag removes a user supplied tag from an album. See: http://www.last.fm/api/show/album.removeTag
func (*AlbumService) Search ¶
func (s *AlbumService) Search(ctx context.Context, album string, options url.Values) (*AlbumSearchResponse, error)
Search searches for an album by name. See: http://www.last.fm/api/show/album.search
type Artist ¶
type Artist struct {
Name string `json:"name"`
MBID string `json:"mbid"`
URL string `json:"url,omitempty"`
Image []Image `json:"image,omitempty"`
Streamable string `json:"streamable,omitempty"`
Stats *Stats `json:"stats,omitempty"`
Similar *Similar `json:"similar,omitempty"`
Tags *Tags `json:"tags,omitempty"`
Bio *Bio `json:"bio,omitempty"`
Match float64 `json:"match,string,omitempty"`
Listeners json.Number `json:"listeners,omitempty"`
Playcount json.Number `json:"playcount,omitempty"`
Tagcount json.Number `json:"tagcount,omitempty"`
Rank json.Number `json:"rank,omitempty"`
}
Artist represents a Last.fm artist.
type ArtistCorrection ¶
ArtistCorrection represents an artist correction.
type ArtistGetCorrectionResponse ¶
type ArtistGetCorrectionResponse struct {
Corrections struct {
Correction ArtistCorrection `json:"correction"`
} `json:"corrections"`
}
ArtistGetCorrectionResponse is the response from artist.getCorrection.
type ArtistGetInfoResponse ¶
type ArtistGetInfoResponse struct {
Artist Artist `json:"artist"`
}
ArtistGetInfoResponse is the response from artist.getInfo.
type ArtistGetSimilarResponse ¶
type ArtistGetSimilarResponse struct {
SimilarArtists struct {
Artist ArtistList `json:"artist"`
Attr struct {
Artist string `json:"artist"`
} `json:"@attr"`
} `json:"similarartists"`
}
ArtistGetSimilarResponse is the response from artist.getSimilar.
type ArtistGetTagsResponse ¶
type ArtistGetTagsResponse struct {
Tags struct {
Tag TagList `json:"tag"`
Artist string `json:"artist"`
} `json:"tags"`
}
ArtistGetTagsResponse is the response from artist.getTags.
type ArtistGetTopAlbumsResponse ¶
type ArtistGetTopAlbumsResponse struct {
TopAlbums struct {
Album AlbumList `json:"album"`
Attr struct {
Artist string `json:"artist"`
Page string `json:"page"`
Total string `json:"total"`
} `json:"@attr"`
} `json:"topalbums"`
}
ArtistGetTopAlbumsResponse is the response from artist.getTopAlbums.
type ArtistGetTopTagsResponse ¶
type ArtistGetTopTagsResponse struct {
TopTags struct {
Tag TagList `json:"tag"`
Artist string `json:"artist"`
} `json:"toptags"`
}
ArtistGetTopTagsResponse is the response from artist.getTopTags.
type ArtistGetTopTracksResponse ¶
type ArtistGetTopTracksResponse struct {
TopTracks struct {
Track TrackList `json:"track"`
Attr struct {
Artist string `json:"artist"`
Page string `json:"page"`
Total string `json:"total"`
} `json:"@attr"`
} `json:"toptracks"`
}
ArtistGetTopTracksResponse is the response from artist.getTopTracks.
type ArtistList ¶
type ArtistList []Artist
ArtistList is a slice of Artist that handles both a single object and an array in JSON.
func (*ArtistList) UnmarshalJSON ¶
func (a *ArtistList) UnmarshalJSON(data []byte) error
UnmarshalJSON implements json.Unmarshaler.
type ArtistSearchResponse ¶
type ArtistSearchResponse struct {
Results struct {
ArtistMatches struct {
Artist ArtistList `json:"artist"`
} `json:"artistmatches"`
} `json:"results"`
}
ArtistSearchResponse is the response from artist.search.
type ArtistService ¶
type ArtistService struct {
// contains filtered or unexported fields
}
ArtistService handles API calls related to artists.
func NewArtistService ¶
func NewArtistService(client APIClient) *ArtistService
NewArtistService creates a new artist service.
func (*ArtistService) AddTags ¶
func (s *ArtistService) AddTags(ctx context.Context, artist, tags string) error
AddTags tags an artist using a list of user supplied tags. See: http://www.last.fm/api/show/artist.addTags
func (*ArtistService) GetCorrection ¶
func (s *ArtistService) GetCorrection(ctx context.Context, artist string) (*ArtistGetCorrectionResponse, error)
GetCorrection checks whether the supplied artist has a correction to a canonical artist. See: http://www.last.fm/api/show/artist.getCorrection
func (*ArtistService) GetInfo ¶
func (s *ArtistService) GetInfo(ctx context.Context, artist string, options url.Values) (*ArtistGetInfoResponse, error)
GetInfo gets the metadata for an artist. See: http://www.last.fm/api/show/artist.getInfo
func (*ArtistService) GetSimilar ¶
func (s *ArtistService) GetSimilar(ctx context.Context, artist string, options url.Values) (*ArtistGetSimilarResponse, error)
GetSimilar gets all the artists similar to this artist. See: http://www.last.fm/api/show/artist.getSimilar
func (*ArtistService) GetTags ¶
func (s *ArtistService) GetTags(ctx context.Context, artist string, options url.Values) (*ArtistGetTagsResponse, error)
GetTags gets the tags applied by an individual user to an artist. See: http://www.last.fm/api/show/artist.getTags
func (*ArtistService) GetTopAlbums ¶
func (s *ArtistService) GetTopAlbums(ctx context.Context, artist string, options url.Values) (*ArtistGetTopAlbumsResponse, error)
GetTopAlbums gets the top albums for an artist on Last.fm, ordered by popularity. See: http://www.last.fm/api/show/artist.getTopAlbums
func (*ArtistService) GetTopTags ¶
func (s *ArtistService) GetTopTags(ctx context.Context, artist string, options url.Values) (*ArtistGetTopTagsResponse, error)
GetTopTags gets the top tags for an artist. See: http://www.last.fm/api/show/artist.getTopTags
func (*ArtistService) GetTopTracks ¶
func (s *ArtistService) GetTopTracks(ctx context.Context, artist string, options url.Values) (*ArtistGetTopTracksResponse, error)
GetTopTracks gets the top tracks by an artist on Last.fm, ordered by popularity. See: http://www.last.fm/api/show/artist.getTopTracks
func (*ArtistService) RemoveTag ¶
func (s *ArtistService) RemoveTag(ctx context.Context, artist, tag string) error
RemoveTag removes a user supplied tag from an artist. See: http://www.last.fm/api/show/artist.removeTag
func (*ArtistService) Search ¶
func (s *ArtistService) Search(ctx context.Context, artist string, options url.Values) (*ArtistSearchResponse, error)
Search searches for an artist by name. See: http://www.last.fm/api/show/artist.search
type Attr ¶
type Attr struct {
Page json.Number `json:"page,omitempty"`
PerPage json.Number `json:"perPage,omitempty"`
TotalPages json.Number `json:"totalPages,omitempty"`
Total json.Number `json:"total,omitempty"`
User string `json:"user,omitempty"`
Country string `json:"country,omitempty"`
Artist string `json:"artist,omitempty"`
Tag string `json:"tag,omitempty"`
From string `json:"from,omitempty"`
To string `json:"to,omitempty"`
}
Attr represents metadata for responses.
type AuthService ¶
type AuthService struct {
// contains filtered or unexported fields
}
AuthService handles authentication-related API calls.
func (*AuthService) AuthURL ¶
func (s *AuthService) AuthURL(token string) string
AuthURL returns the URL the user should be redirected to for authorization. For Web applications, token can be empty. For Desktop, it should be the token from GetToken.
func (*AuthService) GetMobileSession ¶
func (s *AuthService) GetMobileSession(ctx context.Context, username, password string) (Session, error)
GetMobileSession fetches a session key for a mobile application using credentials. Note: This method uses a POST request over HTTPS as required by Last.fm.
func (*AuthService) GetSession ¶
GetSession fetches a web service session for a user. The token should be the one received after user authorization.
type Bio ¶
type Bio struct {
Published string `json:"published"`
Summary string `json:"summary"`
Content string `json:"content"`
}
Bio represents biography information for an artist.
type ChartGetTopArtistsResponse ¶
type ChartGetTopArtistsResponse struct {
Artists struct {
Artist ArtistList `json:"artist"`
Attr Attr `json:"@attr"`
} `json:"artists"`
}
ChartGetTopArtistsResponse is the response from chart.getTopArtists.
type ChartGetTopTagsResponse ¶
type ChartGetTopTagsResponse struct {
Tags struct {
Tag TagList `json:"tag"`
Attr Attr `json:"@attr"`
} `json:"tags"`
}
ChartGetTopTagsResponse is the response from chart.getTopTags.
type ChartGetTopTracksResponse ¶
type ChartGetTopTracksResponse struct {
Tracks struct {
Track TrackList `json:"track"`
Attr Attr `json:"@attr"`
} `json:"tracks"`
}
ChartGetTopTracksResponse is the response from chart.getTopTracks.
type ChartList ¶
type ChartList []Chart
ChartList is a slice of Chart that handles both a single object and an array in JSON.
func (*ChartList) UnmarshalJSON ¶
UnmarshalJSON implements json.Unmarshaler.
type ChartService ¶
type ChartService struct {
// contains filtered or unexported fields
}
ChartService handles API calls related to charts.
func NewChartService ¶
func NewChartService(client APIClient) *ChartService
NewChartService creates a new chart service.
func (*ChartService) GetTopArtists ¶
func (s *ChartService) GetTopArtists(ctx context.Context, options url.Values) (*ChartGetTopArtistsResponse, error)
GetTopArtists gets the top artists chart. See: http://www.last.fm/api/show/chart.getTopArtists
func (*ChartService) GetTopTags ¶
func (s *ChartService) GetTopTags(ctx context.Context, options url.Values) (*ChartGetTopTagsResponse, error)
GetTopTags gets the top tags chart. See: http://www.last.fm/api/show/chart.getTopTags
func (*ChartService) GetTopTracks ¶
func (s *ChartService) GetTopTracks(ctx context.Context, options url.Values) (*ChartGetTopTracksResponse, error)
GetTopTracks gets the top tracks chart. See: http://www.last.fm/api/show/chart.getTopTracks
type Client ¶
type Client struct {
Auth *AuthService
Track *TrackService
Artist *ArtistService
Album *AlbumService
User *UserService
Chart *ChartService
Geo *GeoService
Tag *TagService
Library *LibraryService
// contains filtered or unexported fields
}
Client is a Last.fm API client.
type Friend ¶
type Friend struct {
Name string `json:"name"`
RealName string `json:"realname"`
Image []Image `json:"image"`
URL string `json:"url"`
Country string `json:"country"`
Registered Date `json:"registered"`
}
Friend represents a Last.fm user's friend.
type FriendList ¶
type FriendList []Friend
FriendList is a slice of Friend that handles both a single object and an array in JSON.
func (*FriendList) UnmarshalJSON ¶
func (f *FriendList) UnmarshalJSON(data []byte) error
UnmarshalJSON implements json.Unmarshaler.
type GeoGetTopArtistsResponse ¶
type GeoGetTopArtistsResponse struct {
TopArtists struct {
Artist ArtistList `json:"artist"`
Attr Attr `json:"@attr"`
} `json:"topartists"`
}
GeoGetTopArtistsResponse is the response from geo.getTopArtists.
type GeoGetTopTracksResponse ¶
type GeoGetTopTracksResponse struct {
Tracks struct {
Track TrackList `json:"track"`
Attr Attr `json:"@attr"`
} `json:"tracks"`
}
GeoGetTopTracksResponse is the response from geo.getTopTracks.
type GeoService ¶
type GeoService struct {
// contains filtered or unexported fields
}
GeoService handles API calls related to geography.
func NewGeoService ¶
func NewGeoService(client APIClient) *GeoService
NewGeoService creates a new geo service.
func (*GeoService) GetTopArtists ¶
func (s *GeoService) GetTopArtists(ctx context.Context, country string, options url.Values) (*GeoGetTopArtistsResponse, error)
GetTopArtists gets the most popular artists on Last.fm by country. See: http://www.last.fm/api/show/geo.getTopArtists
func (*GeoService) GetTopTracks ¶
func (s *GeoService) GetTopTracks(ctx context.Context, country string, options url.Values) (*GeoGetTopTracksResponse, error)
GetTopTracks gets the most popular tracks on Last.fm last week by country. See: http://www.last.fm/api/show/geo.getTopTracks
type LibraryGetArtistsResponse ¶
type LibraryGetArtistsResponse struct {
Artists struct {
Artist ArtistList `json:"artist"`
Attr Attr `json:"@attr"`
} `json:"artists"`
}
LibraryGetArtistsResponse is the response from library.getArtists.
type LibraryService ¶
type LibraryService struct {
// contains filtered or unexported fields
}
LibraryService handles API calls related to a user's library.
func NewLibraryService ¶
func NewLibraryService(client APIClient) *LibraryService
NewLibraryService creates a new library service.
func (*LibraryService) GetArtists ¶
func (s *LibraryService) GetArtists(ctx context.Context, user string, options url.Values) (*LibraryGetArtistsResponse, error)
GetArtists gets a paginated list of all the artists in a user's library. See: http://www.last.fm/api/show/library.getArtists
type Option ¶
type Option func(*Client)
Option is a functional option for configuring the client.
func WithHTTPClient ¶
WithHTTPClient sets a custom HTTP client.
func WithSessionKey ¶
WithSessionKey sets the session key for authenticated requests.
func WithUserAgent ¶
WithUserAgent sets a custom User-Agent header.
type ScrobbleResult ¶
type ScrobbleResult struct {
Artist TrackCorrectionEntity `json:"artist"`
Album TrackCorrectionEntity `json:"album"`
Track TrackCorrectionEntity `json:"track"`
Timestamp string `json:"timestamp"`
}
ScrobbleResult represents the result of a single scrobble.
type ScrobbleResults ¶
type ScrobbleResults []ScrobbleResult
ScrobbleResults is a slice of ScrobbleResult that handles both a single object and an array in JSON.
func (*ScrobbleResults) UnmarshalJSON ¶
func (s *ScrobbleResults) UnmarshalJSON(data []byte) error
UnmarshalJSON implements json.Unmarshaler.
type Session ¶
type Session struct {
Name string `json:"name"`
Key string `json:"key"`
Subscriber json.Number `json:"subscriber"`
}
Session represents a Last.fm user session.
type Similar ¶
type Similar struct {
Artist ArtistList `json:"artist,omitempty"`
Tag TagList `json:"tag,omitempty"`
}
Similar represents similar artists or tags.
type Stats ¶
type Stats struct {
Listeners json.Number `json:"listeners"`
Playcount json.Number `json:"playcount"`
}
Stats represents statistics for an artist.
type Streamable ¶
Streamable represents streamable status.
type Tag ¶
type Tag struct {
Name string `json:"name"`
URL string `json:"url"`
Count json.Number `json:"count,omitempty"`
Reach json.Number `json:"reach,omitempty"`
Taggings json.Number `json:"taggings,omitempty"`
Streamable string `json:"streamable,omitempty"`
Wiki *Wiki `json:"wiki,omitempty"`
}
Tag represents a Last.fm tag.
type TagGetInfoResponse ¶
type TagGetInfoResponse struct {
Tag Tag `json:"tag"`
}
TagGetInfoResponse is the response from tag.getInfo.
type TagGetSimilarResponse ¶
type TagGetSimilarResponse struct {
SimilarTags struct {
Tag TagList `json:"tag"`
Attr struct {
Tag string `json:"tag"`
} `json:"@attr"`
} `json:"similartags"`
}
TagGetSimilarResponse is the response from tag.getSimilar.
type TagGetTopAlbumsResponse ¶
type TagGetTopAlbumsResponse struct {
Albums struct {
Album AlbumList `json:"album"`
Attr Attr `json:"@attr"`
} `json:"albums"`
}
TagGetTopAlbumsResponse is the response from tag.getTopAlbums.
type TagGetTopArtistsResponse ¶
type TagGetTopArtistsResponse struct {
TopArtists struct {
Artist ArtistList `json:"artist"`
Attr Attr `json:"@attr"`
} `json:"topartists"`
}
TagGetTopArtistsResponse is the response from tag.getTopArtists.
type TagGetTopTagsResponse ¶
type TagGetTopTagsResponse struct {
TopTags struct {
Tag TagList `json:"tag"`
Attr struct {
NumRes int `json:"num_res"`
Offset int `json:"offset"`
Total int `json:"total"`
} `json:"@attr"`
} `json:"toptags"`
}
TagGetTopTagsResponse is the response from tag.getTopTags.
type TagGetTopTracksResponse ¶
type TagGetTopTracksResponse struct {
Tracks struct {
Track TrackList `json:"track"`
Attr Attr `json:"@attr"`
} `json:"tracks"`
}
TagGetTopTracksResponse is the response from tag.getTopTracks.
type TagGetWeeklyChartListResponse ¶
type TagGetWeeklyChartListResponse struct {
WeeklyChartList struct {
Chart ChartList `json:"chart"`
Attr struct {
Tag string `json:"tag"`
} `json:"@attr"`
} `json:"weeklychartlist"`
}
TagGetWeeklyChartListResponse is the response from tag.getWeeklyChartList.
type TagList ¶
type TagList []Tag
TagList is a slice of Tag that handles both a single object and an array in JSON.
func (*TagList) UnmarshalJSON ¶
UnmarshalJSON implements json.Unmarshaler.
type TagService ¶
type TagService struct {
// contains filtered or unexported fields
}
TagService handles API calls related to tags.
func NewTagService ¶
func NewTagService(client APIClient) *TagService
NewTagService creates a new tag service.
func (*TagService) GetInfo ¶
func (s *TagService) GetInfo(ctx context.Context, tag string, options url.Values) (*TagGetInfoResponse, error)
GetInfo gets the metadata for a tag. See: http://www.last.fm/api/show/tag.getInfo
func (*TagService) GetSimilar ¶
func (s *TagService) GetSimilar(ctx context.Context, tag string, options url.Values) (*TagGetSimilarResponse, error)
GetSimilar gets all the tags similar to this tag. See: http://www.last.fm/api/show/tag.getSimilar
func (*TagService) GetTopAlbums ¶
func (s *TagService) GetTopAlbums(ctx context.Context, tag string, options url.Values) (*TagGetTopAlbumsResponse, error)
GetTopAlbums gets the top albums for a tag. See: http://www.last.fm/api/show/tag.getTopAlbums
func (*TagService) GetTopArtists ¶
func (s *TagService) GetTopArtists(ctx context.Context, tag string, options url.Values) (*TagGetTopArtistsResponse, error)
GetTopArtists gets the top artists for a tag. See: http://www.last.fm/api/show/tag.getTopArtists
func (*TagService) GetTopTags ¶
func (s *TagService) GetTopTags(ctx context.Context, options url.Values) (*TagGetTopTagsResponse, error)
GetTopTags gets the top tags on Last.fm. See: http://www.last.fm/api/show/tag.getTopTags
func (*TagService) GetTopTracks ¶
func (s *TagService) GetTopTracks(ctx context.Context, tag string, options url.Values) (*TagGetTopTracksResponse, error)
GetTopTracks gets the top tracks for a tag. See: http://www.last.fm/api/show/tag.getTopTracks
func (*TagService) GetWeeklyChartList ¶
func (s *TagService) GetWeeklyChartList(ctx context.Context, tag string, options url.Values) (*TagGetWeeklyChartListResponse, error)
GetWeeklyChartList gets a list of available charts for this tag. See: http://www.last.fm/api/show/tag.getWeeklyChartList
type TopTags ¶
type TopTags struct {
Tag TagList `json:"tag"`
}
TopTags represents top tags for an entity.
type Track ¶
type Track struct {
Name string `json:"name"`
Duration json.Number `json:"duration,omitempty"`
MBID string `json:"mbid"`
URL string `json:"url"`
Streamable interface{} `json:"streamable,omitempty"` // Can be string or Streamable struct
Artist interface{} `json:"artist,omitempty"` // Can be string or Artist struct
Album interface{} `json:"album,omitempty"` // Can be string or Album struct
Rank json.Number `json:"rank,omitempty"`
Playcount json.Number `json:"playcount,omitempty"`
Listeners json.Number `json:"listeners,omitempty"`
Image []Image `json:"image,omitempty"`
TopTags *TopTags `json:"toptags,omitempty"`
Wiki *Wiki `json:"wiki,omitempty"`
Date *Date `json:"date,omitempty"`
Attr *TrackAttr `json:"@attr,omitempty"`
}
Track represents a Last.fm track.
type TrackAttr ¶
type TrackAttr struct {
NowPlaying string `json:"nowplaying"`
Rank json.Number `json:"rank,omitempty"`
}
TrackAttr represents metadata for a track (e.g. nowplaying).
type TrackCorrection ¶
type TrackCorrection struct {
Track Track `json:"track"`
}
TrackCorrection represents a track correction.
type TrackCorrectionEntity ¶
type TrackCorrectionEntity struct {
Text string `json:"#text"`
Corrected string `json:"corrected"`
}
TrackCorrectionEntity represents corrected metadata in a scrobble response.
type TrackGetCorrectionResponse ¶
type TrackGetCorrectionResponse struct {
Corrections struct {
Correction TrackCorrection `json:"correction"`
} `json:"corrections"`
}
TrackGetCorrectionResponse is the response from track.getCorrection.
type TrackGetInfoResponse ¶
type TrackGetInfoResponse struct {
Track Track `json:"track"`
}
TrackGetInfoResponse is the response from track.getInfo.
type TrackGetSimilarResponse ¶
type TrackGetSimilarResponse struct {
SimilarTracks struct {
Track TrackList `json:"track"`
Attr struct {
Artist string `json:"artist"`
} `json:"@attr"`
} `json:"similartracks"`
}
TrackGetSimilarResponse is the response from track.getSimilar.
type TrackGetTagsResponse ¶
type TrackGetTagsResponse struct {
Tags struct {
Tag TagList `json:"tag"`
Artist string `json:"artist"`
Track string `json:"track"`
} `json:"tags"`
}
TrackGetTagsResponse is the response from track.getTags.
type TrackGetTopTagsResponse ¶
type TrackGetTopTagsResponse struct {
TopTags struct {
Tag TagList `json:"tag"`
Artist string `json:"artist"`
Track string `json:"track"`
} `json:"toptags"`
}
TrackGetTopTagsResponse is the response from track.getTopTags.
type TrackList ¶
type TrackList []Track
TrackList is a slice of Track that handles both a single object and an array in JSON.
func (*TrackList) UnmarshalJSON ¶
UnmarshalJSON implements json.Unmarshaler.
type TrackNowPlayingResponse ¶
type TrackNowPlayingResponse struct {
NowPlaying struct {
Artist TrackCorrectionEntity `json:"artist"`
Album TrackCorrectionEntity `json:"album"`
Track TrackCorrectionEntity `json:"track"`
Timestamp string `json:"timestamp"`
} `json:"nowplaying"`
}
TrackNowPlayingResponse is the response from track.updateNowPlaying.
type TrackScrobbleResponse ¶
type TrackScrobbleResponse struct {
Scrobbles struct {
Scrobble ScrobbleResults `json:"scrobble"`
Attr struct {
Accepted int `json:"accepted"`
Ignored int `json:"ignored"`
} `json:"@attr"`
} `json:"scrobbles"`
}
TrackScrobbleResponse is the response from track.scrobble.
type TrackSearchResponse ¶
type TrackSearchResponse struct {
Results struct {
TrackMatches struct {
Track TrackList `json:"track"`
} `json:"trackmatches"`
} `json:"results"`
}
TrackSearchResponse is the response from track.search.
type TrackService ¶
type TrackService struct {
// contains filtered or unexported fields
}
TrackService handles API calls related to tracks.
func NewTrackService ¶
func NewTrackService(client APIClient) *TrackService
NewTrackService creates a new track service.
func (*TrackService) AddTags ¶
func (s *TrackService) AddTags(ctx context.Context, artist, track, tags string) error
AddTags tags a track using a list of user supplied tags. See: http://www.last.fm/api/show/track.addTags
func (*TrackService) GetCorrection ¶
func (s *TrackService) GetCorrection(ctx context.Context, artist, track string) (*TrackGetCorrectionResponse, error)
GetCorrection gets the corrected artist/track names. See: http://www.last.fm/api/show/track.getCorrection
func (*TrackService) GetInfo ¶
func (s *TrackService) GetInfo(ctx context.Context, artist, track string, options url.Values) (*TrackGetInfoResponse, error)
GetInfo gets the metadata for a track. See: http://www.last.fm/api/show/track.getInfo
func (*TrackService) GetSimilar ¶
func (s *TrackService) GetSimilar(ctx context.Context, artist, track string, options url.Values) (*TrackGetSimilarResponse, error)
GetSimilar gets similar tracks. See: http://www.last.fm/api/show/track.getSimilar
func (*TrackService) GetTags ¶
func (s *TrackService) GetTags(ctx context.Context, artist, track string, options url.Values) (*TrackGetTagsResponse, error)
GetTags gets the tags applied by an individual user to a track. See: http://www.last.fm/api/show/track.getTags
func (*TrackService) GetTopTags ¶
func (s *TrackService) GetTopTags(ctx context.Context, artist, track string, options url.Values) (*TrackGetTopTagsResponse, error)
GetTopTags gets the top tags for a track. See: http://www.last.fm/api/show/track.getTopTags
func (*TrackService) Love ¶
func (s *TrackService) Love(ctx context.Context, artist, track string) error
Love loves a track. See: http://www.last.fm/api/show/track.love
func (*TrackService) RemoveTag ¶
func (s *TrackService) RemoveTag(ctx context.Context, artist, track, tag string) error
RemoveTag removes a user supplied tag from a track. See: http://www.last.fm/api/show/track.removeTag
func (*TrackService) Scrobble ¶
func (s *TrackService) Scrobble(ctx context.Context, artist, track string, timestamp int64, options url.Values) (*TrackScrobbleResponse, error)
Scrobble adds a track-play to a user's profile. See: http://www.last.fm/api/show/track.scrobble
func (*TrackService) Search ¶
func (s *TrackService) Search(ctx context.Context, track string, options url.Values) (*TrackSearchResponse, error)
Search searches for a track by name. See: http://www.last.fm/api/show/track.search
func (*TrackService) Unlove ¶
func (s *TrackService) Unlove(ctx context.Context, artist, track string) error
Unlove unloves a track. See: http://www.last.fm/api/show/track.unlove
func (*TrackService) UpdateNowPlaying ¶
func (s *TrackService) UpdateNowPlaying(ctx context.Context, artist, track string, options url.Values) (*TrackNowPlayingResponse, error)
UpdateNowPlaying notifies Last.fm that a user has started listening to a track. See: http://www.last.fm/api/show/track.updateNowPlaying
type Tracks ¶
type Tracks struct {
Track TrackList `json:"track"`
}
Tracks represents the tracklist of an album.
type User ¶
type User struct {
Name string `json:"name"`
RealName string `json:"realname"`
Image []Image `json:"image"`
URL string `json:"url"`
Country string `json:"country"`
Age json.Number `json:"age"`
Gender string `json:"gender"`
Subscriber json.Number `json:"subscriber"`
Playcount json.Number `json:"playcount"`
Playlists json.Number `json:"playlists"`
Bootstrap json.Number `json:"bootstrap"`
Registered Date `json:"registered"`
}
User represents a Last.fm user.
type UserGetFriendsResponse ¶
type UserGetFriendsResponse struct {
Friends struct {
User FriendList `json:"user"`
Attr struct {
User string `json:"user"`
Page json.Number `json:"page"`
PerPage json.Number `json:"perPage"`
TotalPages json.Number `json:"totalPages"`
Total json.Number `json:"total"`
} `json:"@attr"`
} `json:"friends"`
}
UserGetFriendsResponse is the response from user.getFriends.
type UserGetInfoResponse ¶
type UserGetInfoResponse struct {
User User `json:"user"`
}
UserGetInfoResponse is the response from user.getInfo.
type UserGetLovedTracksResponse ¶
type UserGetLovedTracksResponse struct {
LovedTracks struct {
Track TrackList `json:"track"`
Attr struct {
User string `json:"user"`
Page json.Number `json:"page"`
PerPage json.Number `json:"perPage"`
TotalPages json.Number `json:"totalPages"`
Total json.Number `json:"total"`
} `json:"@attr"`
} `json:"lovedtracks"`
}
UserGetLovedTracksResponse is the response from user.getLovedTracks.
type UserGetPersonalTagsResponse ¶
type UserGetPersonalTagsResponse struct {
Taggings struct {
Artists *struct {
Artist ArtistList `json:"artist"`
} `json:"artists,omitempty"`
Albums *struct {
Album AlbumList `json:"album"`
} `json:"albums,omitempty"`
Tracks *struct {
Track TrackList `json:"track"`
} `json:"tracks,omitempty"`
Attr struct {
User string `json:"user"`
Tag string `json:"tag"`
Page json.Number `json:"page"`
PerPage json.Number `json:"perPage"`
TotalPages json.Number `json:"totalPages"`
Total json.Number `json:"total"`
} `json:"@attr"`
} `json:"taggings"`
}
UserGetPersonalTagsResponse is the response from user.getPersonalTags.
type UserGetRecentTracksResponse ¶
type UserGetRecentTracksResponse struct {
RecentTracks struct {
Track TrackList `json:"track"`
Attr struct {
User string `json:"user"`
Page json.Number `json:"page"`
PerPage json.Number `json:"perPage"`
TotalPages json.Number `json:"totalPages"`
Total json.Number `json:"total"`
} `json:"@attr"`
} `json:"recenttracks"`
}
UserGetRecentTracksResponse is the response from user.getRecentTracks.
type UserGetTopAlbumsResponse ¶
type UserGetTopAlbumsResponse struct {
TopAlbums struct {
Album AlbumList `json:"album"`
Attr struct {
User string `json:"user"`
Page json.Number `json:"page"`
PerPage json.Number `json:"perPage"`
TotalPages json.Number `json:"totalPages"`
Total json.Number `json:"total"`
} `json:"@attr"`
} `json:"topalbums"`
}
UserGetTopAlbumsResponse is the response from user.getTopAlbums.
type UserGetTopArtistsResponse ¶
type UserGetTopArtistsResponse struct {
TopArtists struct {
Artist ArtistList `json:"artist"`
Attr struct {
User string `json:"user"`
Page json.Number `json:"page"`
PerPage json.Number `json:"perPage"`
TotalPages json.Number `json:"totalPages"`
Total json.Number `json:"total"`
} `json:"@attr"`
} `json:"topartists"`
}
UserGetTopArtistsResponse is the response from user.getTopArtists.
type UserGetTopTagsResponse ¶
type UserGetTopTagsResponse struct {
TopTags struct {
Tag TagList `json:"tag"`
Attr struct {
User string `json:"user"`
} `json:"@attr"`
} `json:"toptags"`
}
UserGetTopTagsResponse is the response from user.getTopTags.
type UserGetTopTracksResponse ¶
type UserGetTopTracksResponse struct {
TopTracks struct {
Track TrackList `json:"track"`
Attr struct {
User string `json:"user"`
Page json.Number `json:"page"`
PerPage json.Number `json:"perPage"`
TotalPages json.Number `json:"totalPages"`
Total json.Number `json:"total"`
} `json:"@attr"`
} `json:"toptracks"`
}
UserGetTopTracksResponse is the response from user.getTopTracks.
type UserGetWeeklyAlbumChartResponse ¶
type UserGetWeeklyAlbumChartResponse struct {
WeeklyAlbumChart struct {
Album AlbumList `json:"album"`
Attr struct {
User string `json:"user"`
From string `json:"from"`
To string `json:"to"`
} `json:"@attr"`
} `json:"weeklyalbumchart"`
}
UserGetWeeklyAlbumChartResponse is the response from user.getWeeklyAlbumChart.
type UserGetWeeklyArtistChartResponse ¶
type UserGetWeeklyArtistChartResponse struct {
WeeklyArtistChart struct {
Artist ArtistList `json:"artist"`
Attr struct {
User string `json:"user"`
From string `json:"from"`
To string `json:"to"`
} `json:"@attr"`
} `json:"weeklyartistchart"`
}
UserGetWeeklyArtistChartResponse is the response from user.getWeeklyArtistChart.
type UserGetWeeklyChartListResponse ¶
type UserGetWeeklyChartListResponse struct {
WeeklyChartList struct {
Chart ChartList `json:"chart"`
Attr struct {
User string `json:"user"`
} `json:"@attr"`
} `json:"weeklychartlist"`
}
UserGetWeeklyChartListResponse is the response from user.getWeeklyChartList.
type UserGetWeeklyTrackChartResponse ¶
type UserGetWeeklyTrackChartResponse struct {
WeeklyTrackChart struct {
Track TrackList `json:"track"`
Attr struct {
User string `json:"user"`
From string `json:"from"`
To string `json:"to"`
} `json:"@attr"`
} `json:"weeklytrackchart"`
}
UserGetWeeklyTrackChartResponse is the response from user.getWeeklyTrackChart.
type UserService ¶
type UserService struct {
// contains filtered or unexported fields
}
UserService handles API calls related to users.
func NewUserService ¶
func NewUserService(client APIClient) *UserService
NewUserService creates a new user service.
func (*UserService) GetFriends ¶
func (s *UserService) GetFriends(ctx context.Context, user string, options url.Values) (*UserGetFriendsResponse, error)
GetFriends gets the friends for a user. See: http://www.last.fm/api/show/user.getFriends
func (*UserService) GetInfo ¶
func (s *UserService) GetInfo(ctx context.Context, user string, options url.Values) (*UserGetInfoResponse, error)
GetInfo gets the metadata for a user. See: http://www.last.fm/api/show/user.getInfo
func (*UserService) GetLovedTracks ¶
func (s *UserService) GetLovedTracks(ctx context.Context, user string, options url.Values) (*UserGetLovedTracksResponse, error)
GetLovedTracks gets the loved tracks for a user. See: http://www.last.fm/api/show/user.getLovedTracks
func (*UserService) GetPersonalTags ¶
func (s *UserService) GetPersonalTags(ctx context.Context, user, tag, taggingType string, options url.Values) (*UserGetPersonalTagsResponse, error)
GetPersonalTags gets the user's personal tags. See: http://www.last.fm/api/show/user.getPersonalTags
func (*UserService) GetRecentTracks ¶
func (s *UserService) GetRecentTracks(ctx context.Context, user string, options url.Values) (*UserGetRecentTracksResponse, error)
GetRecentTracks gets a list of the recent tracks listened to by this user. See: http://www.last.fm/api/show/user.getRecentTracks
func (*UserService) GetTopAlbums ¶
func (s *UserService) GetTopAlbums(ctx context.Context, user string, options url.Values) (*UserGetTopAlbumsResponse, error)
GetTopAlbums gets the top albums listened to by a user. See: http://www.last.fm/api/show/user.getTopAlbums
func (*UserService) GetTopArtists ¶
func (s *UserService) GetTopArtists(ctx context.Context, user string, options url.Values) (*UserGetTopArtistsResponse, error)
GetTopArtists gets the top artists listened to by a user. See: http://www.last.fm/api/show/user.getTopArtists
func (*UserService) GetTopTags ¶
func (s *UserService) GetTopTags(ctx context.Context, user string, options url.Values) (*UserGetTopTagsResponse, error)
GetTopTags gets the top tags for a user. See: http://www.last.fm/api/show/user.getTopTags
func (*UserService) GetTopTracks ¶
func (s *UserService) GetTopTracks(ctx context.Context, user string, options url.Values) (*UserGetTopTracksResponse, error)
GetTopTracks gets the top tracks listened to by a user. See: http://www.last.fm/api/show/user.getTopTracks
func (*UserService) GetWeeklyAlbumChart ¶
func (s *UserService) GetWeeklyAlbumChart(ctx context.Context, user string, options url.Values) (*UserGetWeeklyAlbumChartResponse, error)
GetWeeklyAlbumChart gets the weekly album chart for a user. See: http://www.last.fm/api/show/user.getWeeklyAlbumChart
func (*UserService) GetWeeklyArtistChart ¶
func (s *UserService) GetWeeklyArtistChart(ctx context.Context, user string, options url.Values) (*UserGetWeeklyArtistChartResponse, error)
GetWeeklyArtistChart gets the weekly artist chart for a user. See: http://www.last.fm/api/show/user.getWeeklyArtistChart
func (*UserService) GetWeeklyChartList ¶
func (s *UserService) GetWeeklyChartList(ctx context.Context, user string) (*UserGetWeeklyChartListResponse, error)
GetWeeklyChartList gets a list of available weekly charts for a user. See: http://www.last.fm/api/show/user.getWeeklyChartList
func (*UserService) GetWeeklyTrackChart ¶
func (s *UserService) GetWeeklyTrackChart(ctx context.Context, user string, options url.Values) (*UserGetWeeklyTrackChartResponse, error)
GetWeeklyTrackChart gets the weekly track chart for a user. See: http://www.last.fm/api/show/user.getWeeklyTrackChart
Source Files
¶
Directories
¶
| Path | Synopsis |
|---|---|
|
examples
|
|
|
auth_desktop
command
|
|
|
auth_mobile
command
|
|
|
music_discovery
command
|
|
|
scrobble_and_love
command
|
|
|
internal
|
|